# -*- coding: utf-8 -*-

from django_cas_ng.backends import CASBackend
from django.core.mail import mail_admins

from ldapaccounts.models import LdapUser
from accounts.utils import update_user
from accounts.models import User


class AccountsCASBackend(CASBackend):
    def configure_user(self, user):
        login_mail = LdapUser.objects.filter(mail=user.email)
        if len(login_mail) == 1:
            # l'utilisateur existe dans le ldap
            ldap_user = login_mail.first()
            conflit = User.objects.filter(login_inp_net=ldap_user.login_inp_net)
            if len(conflit) > 1:
                # plusieurs comptes ont déjà le même login INP-net
                mail_admins(
                    "Conflit login INP-net",
                    "Plusieurs comptes billetterie sont "
                    "associés au même login INP-net {}".format(ldap_user.login_inp_net),
                )
                user.delete()
                return None
            elif len(conflit) == 1:
                mail_admins(
                    "Conflit login INP-net",
                    "Un nouveau compte billetterie essaye de se créer avec un login INP-net déjà associé. \n"
                    "Login : {}\nAncienne adresse : {}\nNouvelle adresse : {}".format(
                        ldap_user.login_inp_net, conflit[0].email, user.email
                    ),
                )
                user.delete()
                return None
            else:
                # pas de conflit
                user.login_inp_net = ldap_user.login_inp_net
                user.set_unusable_password()
                user.is_active = True
                user.save()
                update_user(user)
                return user

        else:
            # pas de correspondance ou plusieurs
            user.delete()
            return None
